# eric7.Snapshot.SnapshotWaylandGrabber

Module implementing a grabber object for non-Wayland desktops.

### Global Attributes

None

### Classes

SnapshotWaylandGrabber | Class implementing a grabber object for non-Wayland desktops.

### Functions

None

## SnapshotWaylandGrabber

Class implementing a grabber object for non-Wayland desktops.

### Signals

grabbed(QPixmap)
  emitted after the grab operation is finished

### Derived from

QObject

### Class Attributes

None

### Class Methods

None

### Methods

SnapshotWaylandGrabber | Constructor
__checkReply | Private method to check, if a reply is valid.
__grabFullscreen | Private method to grab the complete desktop.
__grabRectangle | Private method to grab a rectangular desktop area.
__grabSelectedScreen | Private method to grab a selected screen.
__grabSelectedWindow | Private method to grab a selected window.
__performGrab | Private method to perform the grab operations.
__temporaryFilename | Private method to generate a temporary filename.
grab | Public method to perform a grab operation potentially after a delay.
supportedModes | Public method to get the supported screenshot modes.

### Static Methods

None

#### SnapshotWaylandGrabber (Constructor)

SnapshotWaylandGrabber(parent=None)

Constructor

parent (QObject)
  reference to the parent object

#### SnapshotWaylandGrabber.__checkReply

__checkReply(reply, argumentsCount)

Private method to check, if a reply is valid.

reply (QDBusMessage)
  reference to the reply message
argumentsCount (int)
  number of expected arguments

Return:
  flag indicating validity

Return Type:
  bool

#### SnapshotWaylandGrabber.__grabFullscreen

__grabFullscreen()

Private method to grab the complete desktop.

#### SnapshotWaylandGrabber.__grabRectangle

__grabRectangle()

Private method to grab a rectangular desktop area.

#### SnapshotWaylandGrabber.__grabSelectedScreen

__grabSelectedScreen()

Private method to grab a selected screen.

#### SnapshotWaylandGrabber.__grabSelectedWindow

__grabSelectedWindow()

Private method to grab a selected window.

#### SnapshotWaylandGrabber.__performGrab

__performGrab()

Private method to perform the grab operations.

Raises RuntimeError:
  raised to indicate an unsupported grab mode

#### SnapshotWaylandGrabber.__temporaryFilename

__temporaryFilename()

Private method to generate a temporary filename.

Return:
  path name for a unique, temporary file

Return Type:
  str

#### SnapshotWaylandGrabber.grab

grab(mode, delay=0, captureCursor=False, captureDecorations=False)

Public method to perform a grab operation potentially after a delay.

mode (ScreenshotModes)
  screenshot mode
delay (int)
  delay in seconds
captureCursor (bool)
  flag indicating to include the mouse cursor
captureDecorations (bool)
  flag indicating to include the window decorations (only used for mode SnapshotModes.SELECTEDWINDOW)

#### SnapshotWaylandGrabber.supportedModes

supportedModes()

Public method to get the supported screenshot modes.

Return:
  tuple of supported screenshot modes

Return Type:
  tuple of SnapshotModes

Up